# Table of Contents

- [workspace-best-practice-report](<./workspace-best-practice-report.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Custom Reports: Workspace Best Practice](<./Custom-Reports-Workspace-Best-Practice.md>)
  - [What is the Workspace Best Practice Report?](<./Custom-Reports-Workspace-Best-Practice/What-is-the-Workspace-Best-Practice-Report.md>)
  - [How to Use It](<./Custom-Reports-Workspace-Best-Practice/How-to-Use-It.md>)
  - [How to Add the Workspace Best Practice Report to Your Workspace](<./Custom-Reports-Workspace-Best-Practice/How-to-Add-the-Workspace-Best-Practice-Report-to-Your-Workspace.md>)
